/** \file main.c
 *
 * \brief GPIO: LEDs.
 *
 * This example program switches LEDs on and off.
 *
 * The relevant registers are:
 * - DDRn: Data Direction Register
 * - PORTn: Data Output Value
 *
 * Please see modules 4.2.1 and 4.3.3 for more information.
 * 
 * \author    Wolfgang Neff
 * \version   1.1
 * \date      2018-07-22
 *
 * \par History
 *      Created: 2017-11-27 \n
 *      Modified: 2018-07-22
 */

// Include the modules used by this program.
#include <avr/io.h>
#include <util/delay.h>

#include "board.h"

// At first we want to have the following initial state: LED0: on, LED1: off.
// Then we want that LED1 is blinking. The definitions for the microcontroller
// come from module avr/io.h. The definition for the delay routine comes from
// util/delay and the definitions for the board come from board.h. avr/io.h 
// and util/delay are system modules. board.h is a user module.
/***** This is the main program. *****/
int main(void)
{
	/***** Initialize Hardware *****/
	// At first we specify the initial state. The LEDs are active low (see board.h).
	// So we have to set the pins to switch them off. LED1 is switched off.
    LED_PORT = (1 << LED1);
	// LEDs need power to light up. Therefore pin 0 and 1 must be output.
    LED_DDR = (1 << LED0) | (1 << LED1);
	/***** Use Hardware *****/
	// The super loop is the section where the hardware is used and controlled.
	// We want that LED1 is blinking.
    while(1)
    {
		// Switch LED1 . The LED is active low. So we clear the pin.
		// Please see module 4.3.1 for the details on bit manipulation.
        LED_PORT &= ~(1 << LED1);
		// Let's wait a bit.
	    _delay_ms(500);
		// Switch LED1off again.
        LED_PORT |= (1 << LED1);
		// Let's wait again a bit.
	    _delay_ms(500);
    }
}

