/** \file main.c
 *
 * \brief GPIO: push-buttons.
 *
 * This example program checks if push-buttons are pressed.
 *
 * The relevant registers are:
 * - DDRn: Data Direction Register
 * - PINn: Data Input Value Register
 * - PORTn: Pull-Up Configuration Register
 *
 * \author    Wolfgang Neff
 * \version   1.1
 * \date      2018-07-22
 *
 * \par History
 *      Created: 2017-11-27 \n
 *      Modified: 2018-07-22
 */

#include <avr/io.h>
#include "board.h"

// We want to switch LED1 on if button 1 is pressed and
// we want to switch it off if button 2 is pressed.
int main(void)
{
	/***** Initialize the LED. *****/
	LED_DDR = (1 << LED1);
	LED_PORT = (1 << LED1);
	/***** Initialize the push-buttons. *****/
	// Push-buttons require pull resistors. Our push-buttons are active low.
	// So we activate the pull up resistors. Buttons and LEDs share the same
	// port. So we have to use bit manipulation to keep the LED settings.
	BUTTON_PORT |= ((1 << BUTTON1) | (1 << BUTTON2));
	/***** Super loop *****/
	// This is the control section.
	while(1)
	{
		// We check if button 1 is pressed. Attention: the push buttons are active low.
		// Please see module 4.3.1 for the details on bit manipulation.
		if (!(BUTTON_PIN & (1 << BUTTON1))) {
			// Switch LED on
			LED_PORT &= ~(1 << LED1);
		}
		// We check if button 2 is pressed.
		if (!(BUTTON_PIN & (1 << BUTTON2))) {
			// Switch LED off
			LED_PORT |= (1 << LED1);
		}
	}
}
