/** \file main.c
 *
 * \brief GPIO: debouncing push-buttons.
 *
 * This example program demonstrates the use of a debouncing routine.
 *
 * Please see module 4.2.3 for more information.
 *
 * \note
 * This example uses a user defined module. A user module consists of two files: the header file (.h)
 * and the source code (.c). Both files must be copied into the folder where main.c is. Then both
 * files have to be included into the project: right click on the project (not the solution), select
 * Add/Existing item..., add the files. 
 *
 * \author    Wolfgang Neff
 * \version   1.0
 * \date      2018-07-22
 *
 * \par History
 *      Created: 2017-11-27 \n
 *      Modified: 2018-07-22
 */

#include <avr/io.h>

#include "board.h"
#include "switch.h"

// We use push-button 1 to switch LED 1 on and off. As we use the push-button as a
// switch we have to debounce. We use a piece of software to debounce. The debounce
// routine is called SWITCHn_PRESSED() and is defined in module switch.h.
int main(void)
{
	// Initialize LED.
	LED_DDR = (1 << LED1);
	LED_PORT = (1 << LED1);
	// Initialize button.
	BUTTON_PORT |= (1 << BUTTON1);
	while(1)
	{
		// Use push-buttons as a switch to toggle LEDs.
		if (SWITCH1_PRESSED()) {
			LED_PORT ^= (1 << LED1);
		}
	}
}
