/*
 * console.c
 *
 * Version: 1.1
 * Created: 2017-11-27
 * Modified: 2018-07-22
 *  Author: Wolfgang Neff
 */ 

#include <avr/io.h>

#include "board.h"
#include "console.h"

static FILE console_in = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_READ);
static FILE console_out = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_WRITE);

static int usart_getc(FILE *stream)
{
	while (!(USB_USART_UCSRA & (1 << RXC1)));
	char data = USB_USART_UDR;
	return data=='\r' ? '\n' : data;
}

static int usart_putc(char c, FILE *stream)
{
	if (c == '\n') usart_putc('\r', stream);
	while (!(USB_USART_UCSRA & (1 << UDRE1)));
	USB_USART_UDR = c;
	return 0;
}

void console_init(void)
{
    // Initialize USB USART
	USB_USART_PORT |= (1 << USB_USART_TX);
	USB_USART_DDR |= (1 << USB_USART_TX);
	USB_USART_DDR &= ~(1 << USB_USART_RX);
	USB_USART_UBRR = USB_USART_BAUDRATE;
	USB_USART_UCSRC = USB_USART_CONFIG;
	USB_USART_UCSRB = ((1 << RXEN1) | (1 << TXEN1));
	// Initialize stdin, stdout and stderr
	console_in.get = usart_getc;
	console_out.put = usart_putc;
    stdin  = &console_in;
	stderr = &console_out;
	stdout = &console_out;
}

void console_clear(void)
{
	putchar('\x1B');
	putchar('[');
	putchar('2');
	putchar('J');
	putchar('\x1B');
	putchar('[');
	putchar('H');
}
