/** \file console.h
 *
 * \brief Connect stdio with the USB-USART gateway.
 *
 * This module connects stdio with the USB-USART gateway (USART1) so that
 * the standard input/output functions such as getchar, putchar, gets,
 * puts, printf and scanf can be used with the console (PuTTY or KiTTY).
 *
 * \author    Wolfgang Neff
 * \version   1.1
 * \date      2018-07-22
 *
 * \par History
 *      Created: 2017-11-27 \n
 *      Modified: 2018-07-22
 *
 * \note USART parameters: 57600 8N1
 */

#ifndef CONSOLE_H_
#define CONSOLE_H_

#include <stdio.h>

#ifdef __cplusplus
extern "C"
{
#endif

/// <summary>Connect stdio with the USB-USART gateway.</summary>
/// <remarks>
/// This routine initializes the USB-USART gateway (USART1) and links
/// it with stdio.
/// </remarks>
void console_init(void);

/// <summary>Clear screen.</summary>
/// <remarks>
/// This routine erases the screen with the background color and moves
/// the cursor to its home position. This routine requires an ANSI/VT100
/// compatible terminal.
/// </remarks>
void console_clear(void);

#ifdef __cplusplus
}
#endif

#endif /* CONSOLE_H_ */
